Documentation
¶
Index ¶
- Constants
- Variables
- func DevtoolBuilder() *devtoolBuilder
- func RegisterDevtoolServiceServer(s grpc.ServiceRegistrar, srv DevtoolServiceServer)
- type Controller
- type Devtool
- type DevtoolServiceClient
- type DevtoolServiceServer
- type GetConfigurationRequest
- type GetConfigurationResponse
- func (*GetConfigurationResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetConfigurationResponse) GetController() *Controller
- func (*GetConfigurationResponse) ProtoMessage()
- func (x *GetConfigurationResponse) ProtoReflect() protoreflect.Message
- func (x *GetConfigurationResponse) Reset()
- func (x *GetConfigurationResponse) String() string
- type Layer
- type LayerScope
- type RESTComponent
- func (*RESTComponent) Descriptor() ([]byte, []int)deprecated
- func (x *RESTComponent) GetExceptionFilters() []*Layer
- func (x *RESTComponent) GetGuards() []*Layer
- func (x *RESTComponent) GetHandler() string
- func (x *RESTComponent) GetHttpMethod() string
- func (x *RESTComponent) GetId() string
- func (x *RESTComponent) GetInterceptors() []*Layer
- func (x *RESTComponent) GetMiddlewares() []*Layer
- func (x *RESTComponent) GetRequest() *RESTRequest
- func (x *RESTComponent) GetRoute() string
- func (x *RESTComponent) GetVersioning() *RESTVersioning
- func (*RESTComponent) ProtoMessage()
- func (x *RESTComponent) ProtoReflect() protoreflect.Message
- func (x *RESTComponent) Reset()
- func (x *RESTComponent) String() string
- type RESTRequest
- func (*RESTRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RESTRequest) GetBody() []*Schema
- func (x *RESTRequest) GetFile() []*Schema
- func (x *RESTRequest) GetForm() []*Schema
- func (x *RESTRequest) GetHeader() []*Schema
- func (x *RESTRequest) GetParam() []*Schema
- func (x *RESTRequest) GetQuery() []*Schema
- func (*RESTRequest) ProtoMessage()
- func (x *RESTRequest) ProtoReflect() protoreflect.Message
- func (x *RESTRequest) Reset()
- func (x *RESTRequest) String() string
- type RESTVersioning
- func (*RESTVersioning) Descriptor() ([]byte, []int)deprecated
- func (x *RESTVersioning) GetKey() string
- func (x *RESTVersioning) GetType() int32
- func (x *RESTVersioning) GetValue() string
- func (*RESTVersioning) ProtoMessage()
- func (x *RESTVersioning) ProtoReflect() protoreflect.Message
- func (x *RESTVersioning) Reset()
- func (x *RESTVersioning) String() string
- type Schema
- func (*Schema) Descriptor() ([]byte, []int)deprecated
- func (x *Schema) GetFormat() string
- func (x *Schema) GetItem() *Schema
- func (x *Schema) GetName() string
- func (x *Schema) GetProperties() []*Schema
- func (x *Schema) GetType() string
- func (*Schema) ProtoMessage()
- func (x *Schema) ProtoReflect() protoreflect.Message
- func (x *Schema) Reset()
- func (x *Schema) String() string
- type UnimplementedDevtoolServiceServer
- type UnsafeDevtoolServiceServer
Constants ¶
const (
DevtoolService_GetConfiguration_FullMethodName = "/devtool.DevtoolService/GetConfiguration"
)
Variables ¶
var ( LayerScope_name = map[int32]string{ 0: "UNKNOWN", 1: "REQUEST_SCOPE", 2: "GLOBAL_SCOPE", } LayerScope_value = map[string]int32{ "UNKNOWN": 0, "REQUEST_SCOPE": 1, "GLOBAL_SCOPE": 2, } )
Enum value maps for LayerScope.
var DevtoolService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "devtool.DevtoolService", HandlerType: (*DevtoolServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetConfiguration", Handler: _DevtoolService_GetConfiguration_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "devtool/devtool.proto", }
DevtoolService_ServiceDesc is the grpc.ServiceDesc for DevtoolService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_devtool_devtool_proto protoreflect.FileDescriptor
Functions ¶
func DevtoolBuilder ¶
func DevtoolBuilder() *devtoolBuilder
func RegisterDevtoolServiceServer ¶
func RegisterDevtoolServiceServer(s grpc.ServiceRegistrar, srv DevtoolServiceServer)
Types ¶
type Controller ¶
type Controller struct {
Rest []*RESTComponent `protobuf:"bytes,1,rep,name=rest,proto3" json:"rest,omitempty"`
// contains filtered or unexported fields
}
func (*Controller) Descriptor
deprecated
func (*Controller) Descriptor() ([]byte, []int)
Deprecated: Use Controller.ProtoReflect.Descriptor instead.
func (*Controller) GetRest ¶
func (x *Controller) GetRest() []*RESTComponent
func (*Controller) ProtoMessage ¶
func (*Controller) ProtoMessage()
func (*Controller) ProtoReflect ¶
func (x *Controller) ProtoReflect() protoreflect.Message
func (*Controller) Reset ¶
func (x *Controller) Reset()
func (*Controller) String ¶
func (x *Controller) String() string
type Devtool ¶
type Devtool struct {
GetConfigurationResponse
DevtoolServiceServer
}
func (*Devtool) GetConfiguration ¶
func (devtool *Devtool) GetConfiguration(context.Context, *GetConfigurationRequest) (*GetConfigurationResponse, error)
type DevtoolServiceClient ¶
type DevtoolServiceClient interface {
GetConfiguration(ctx context.Context, in *GetConfigurationRequest, opts ...grpc.CallOption) (*GetConfigurationResponse, error)
}
DevtoolServiceClient is the client API for DevtoolService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewDevtoolServiceClient ¶
func NewDevtoolServiceClient(cc grpc.ClientConnInterface) DevtoolServiceClient
type DevtoolServiceServer ¶
type DevtoolServiceServer interface {
GetConfiguration(context.Context, *GetConfigurationRequest) (*GetConfigurationResponse, error)
// contains filtered or unexported methods
}
DevtoolServiceServer is the server API for DevtoolService service. All implementations must embed UnimplementedDevtoolServiceServer for forward compatibility.
type GetConfigurationRequest ¶
type GetConfigurationRequest struct {
// contains filtered or unexported fields
}
func (*GetConfigurationRequest) Descriptor
deprecated
func (*GetConfigurationRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetConfigurationRequest.ProtoReflect.Descriptor instead.
func (*GetConfigurationRequest) ProtoMessage ¶
func (*GetConfigurationRequest) ProtoMessage()
func (*GetConfigurationRequest) ProtoReflect ¶
func (x *GetConfigurationRequest) ProtoReflect() protoreflect.Message
func (*GetConfigurationRequest) Reset ¶
func (x *GetConfigurationRequest) Reset()
func (*GetConfigurationRequest) String ¶
func (x *GetConfigurationRequest) String() string
type GetConfigurationResponse ¶
type GetConfigurationResponse struct {
Controller *Controller `protobuf:"bytes,1,opt,name=controller,proto3" json:"controller,omitempty"`
// contains filtered or unexported fields
}
func (*GetConfigurationResponse) Descriptor
deprecated
func (*GetConfigurationResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetConfigurationResponse.ProtoReflect.Descriptor instead.
func (*GetConfigurationResponse) GetController ¶
func (x *GetConfigurationResponse) GetController() *Controller
func (*GetConfigurationResponse) ProtoMessage ¶
func (*GetConfigurationResponse) ProtoMessage()
func (*GetConfigurationResponse) ProtoReflect ¶
func (x *GetConfigurationResponse) ProtoReflect() protoreflect.Message
func (*GetConfigurationResponse) Reset ¶
func (x *GetConfigurationResponse) Reset()
func (*GetConfigurationResponse) String ¶
func (x *GetConfigurationResponse) String() string
type Layer ¶
type Layer struct {
Scope LayerScope `protobuf:"varint,1,opt,name=scope,proto3,enum=devtool.LayerScope" json:"scope,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*Layer) Descriptor
deprecated
func (*Layer) GetScope ¶
func (x *Layer) GetScope() LayerScope
func (*Layer) ProtoMessage ¶
func (*Layer) ProtoMessage()
func (*Layer) ProtoReflect ¶
func (x *Layer) ProtoReflect() protoreflect.Message
type LayerScope ¶
type LayerScope int32
const ( LayerScope_UNKNOWN LayerScope = 0 LayerScope_REQUEST_SCOPE LayerScope = 1 LayerScope_GLOBAL_SCOPE LayerScope = 2 )
func (LayerScope) Descriptor ¶
func (LayerScope) Descriptor() protoreflect.EnumDescriptor
func (LayerScope) Enum ¶
func (x LayerScope) Enum() *LayerScope
func (LayerScope) EnumDescriptor
deprecated
func (LayerScope) EnumDescriptor() ([]byte, []int)
Deprecated: Use LayerScope.Descriptor instead.
func (LayerScope) Number ¶
func (x LayerScope) Number() protoreflect.EnumNumber
func (LayerScope) String ¶
func (x LayerScope) String() string
func (LayerScope) Type ¶
func (LayerScope) Type() protoreflect.EnumType
type RESTComponent ¶
type RESTComponent struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Handler string `protobuf:"bytes,2,opt,name=handler,proto3" json:"handler,omitempty"`
HttpMethod string `protobuf:"bytes,3,opt,name=http_method,json=httpMethod,proto3" json:"http_method,omitempty"`
Route string `protobuf:"bytes,4,opt,name=route,proto3" json:"route,omitempty"`
ExceptionFilters []*Layer `protobuf:"bytes,5,rep,name=exception_filters,json=exceptionFilters,proto3" json:"exception_filters,omitempty"`
Middlewares []*Layer `protobuf:"bytes,6,rep,name=middlewares,proto3" json:"middlewares,omitempty"`
Guards []*Layer `protobuf:"bytes,7,rep,name=guards,proto3" json:"guards,omitempty"`
Interceptors []*Layer `protobuf:"bytes,8,rep,name=interceptors,proto3" json:"interceptors,omitempty"`
Versioning *RESTVersioning `protobuf:"bytes,9,opt,name=versioning,proto3" json:"versioning,omitempty"`
Request *RESTRequest `protobuf:"bytes,10,opt,name=request,proto3" json:"request,omitempty"`
// contains filtered or unexported fields
}
func (*RESTComponent) Descriptor
deprecated
func (*RESTComponent) Descriptor() ([]byte, []int)
Deprecated: Use RESTComponent.ProtoReflect.Descriptor instead.
func (*RESTComponent) GetExceptionFilters ¶
func (x *RESTComponent) GetExceptionFilters() []*Layer
func (*RESTComponent) GetGuards ¶
func (x *RESTComponent) GetGuards() []*Layer
func (*RESTComponent) GetHandler ¶
func (x *RESTComponent) GetHandler() string
func (*RESTComponent) GetHttpMethod ¶
func (x *RESTComponent) GetHttpMethod() string
func (*RESTComponent) GetId ¶
func (x *RESTComponent) GetId() string
func (*RESTComponent) GetInterceptors ¶
func (x *RESTComponent) GetInterceptors() []*Layer
func (*RESTComponent) GetMiddlewares ¶
func (x *RESTComponent) GetMiddlewares() []*Layer
func (*RESTComponent) GetRequest ¶
func (x *RESTComponent) GetRequest() *RESTRequest
func (*RESTComponent) GetRoute ¶
func (x *RESTComponent) GetRoute() string
func (*RESTComponent) GetVersioning ¶
func (x *RESTComponent) GetVersioning() *RESTVersioning
func (*RESTComponent) ProtoMessage ¶
func (*RESTComponent) ProtoMessage()
func (*RESTComponent) ProtoReflect ¶
func (x *RESTComponent) ProtoReflect() protoreflect.Message
func (*RESTComponent) Reset ¶
func (x *RESTComponent) Reset()
func (*RESTComponent) String ¶
func (x *RESTComponent) String() string
type RESTRequest ¶
type RESTRequest struct {
Body []*Schema `protobuf:"bytes,1,rep,name=body,proto3" json:"body,omitempty"`
Form []*Schema `protobuf:"bytes,2,rep,name=form,proto3" json:"form,omitempty"`
Query []*Schema `protobuf:"bytes,3,rep,name=query,proto3" json:"query,omitempty"`
Header []*Schema `protobuf:"bytes,4,rep,name=header,proto3" json:"header,omitempty"`
Param []*Schema `protobuf:"bytes,5,rep,name=param,proto3" json:"param,omitempty"`
File []*Schema `protobuf:"bytes,6,rep,name=file,proto3" json:"file,omitempty"`
// contains filtered or unexported fields
}
func (*RESTRequest) Descriptor
deprecated
func (*RESTRequest) Descriptor() ([]byte, []int)
Deprecated: Use RESTRequest.ProtoReflect.Descriptor instead.
func (*RESTRequest) GetBody ¶
func (x *RESTRequest) GetBody() []*Schema
func (*RESTRequest) GetFile ¶
func (x *RESTRequest) GetFile() []*Schema
func (*RESTRequest) GetForm ¶
func (x *RESTRequest) GetForm() []*Schema
func (*RESTRequest) GetHeader ¶
func (x *RESTRequest) GetHeader() []*Schema
func (*RESTRequest) GetParam ¶
func (x *RESTRequest) GetParam() []*Schema
func (*RESTRequest) GetQuery ¶
func (x *RESTRequest) GetQuery() []*Schema
func (*RESTRequest) ProtoMessage ¶
func (*RESTRequest) ProtoMessage()
func (*RESTRequest) ProtoReflect ¶
func (x *RESTRequest) ProtoReflect() protoreflect.Message
func (*RESTRequest) Reset ¶
func (x *RESTRequest) Reset()
func (*RESTRequest) String ¶
func (x *RESTRequest) String() string
type RESTVersioning ¶
type RESTVersioning struct {
Type int32 `protobuf:"varint,1,opt,name=type,proto3" json:"type,omitempty"`
Value string `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
Key string `protobuf:"bytes,3,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*RESTVersioning) Descriptor
deprecated
func (*RESTVersioning) Descriptor() ([]byte, []int)
Deprecated: Use RESTVersioning.ProtoReflect.Descriptor instead.
func (*RESTVersioning) GetKey ¶
func (x *RESTVersioning) GetKey() string
func (*RESTVersioning) GetType ¶
func (x *RESTVersioning) GetType() int32
func (*RESTVersioning) GetValue ¶
func (x *RESTVersioning) GetValue() string
func (*RESTVersioning) ProtoMessage ¶
func (*RESTVersioning) ProtoMessage()
func (*RESTVersioning) ProtoReflect ¶
func (x *RESTVersioning) ProtoReflect() protoreflect.Message
func (*RESTVersioning) Reset ¶
func (x *RESTVersioning) Reset()
func (*RESTVersioning) String ¶
func (x *RESTVersioning) String() string
type Schema ¶
type Schema struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
Format string `protobuf:"bytes,3,opt,name=format,proto3" json:"format,omitempty"`
Item *Schema `protobuf:"bytes,4,opt,name=item,proto3" json:"item,omitempty"`
Properties []*Schema `protobuf:"bytes,5,rep,name=properties,proto3" json:"properties,omitempty"`
// contains filtered or unexported fields
}
func (*Schema) Descriptor
deprecated
func (*Schema) GetProperties ¶
func (*Schema) ProtoMessage ¶
func (*Schema) ProtoMessage()
func (*Schema) ProtoReflect ¶
func (x *Schema) ProtoReflect() protoreflect.Message
type UnimplementedDevtoolServiceServer ¶
type UnimplementedDevtoolServiceServer struct{}
UnimplementedDevtoolServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedDevtoolServiceServer) GetConfiguration ¶
func (UnimplementedDevtoolServiceServer) GetConfiguration(context.Context, *GetConfigurationRequest) (*GetConfigurationResponse, error)
type UnsafeDevtoolServiceServer ¶
type UnsafeDevtoolServiceServer interface {
// contains filtered or unexported methods
}
UnsafeDevtoolServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DevtoolServiceServer will result in compilation errors.